@@ -14,14 +14,29 @@
 #'   and \code{expected_lines_filename} that contain the
 #'   section under investigation, so that a diff tool
 #'   can compare these
+#' @examples
+#' check_empty_beautier_folder()
+#'
+#' # Creates temporary files in beautier folder
+#' compare_lines(
+#'   lines = readLines(beautier::get_beautier_path("bd_2_4.xml")),
+#'   expected = readLines(beautier::get_beautier_path("bd_2_4.xml"))
+#' )
+#'
+#' remove_beautier_folder()
+#' check_empty_beautier_folder()
 #' @author Richèl J.C. Bilderbeek
 #' @export
 compare_lines <- function(
   lines,
   expected,
   section = NA,
-  created_lines_filename = "created.xml",
-  expected_lines_filename = "expected.xml"
+  created_lines_filename = get_beautier_tempfilename(
+    pattern = "created", fileext = ".xml"
+  ),
+  expected_lines_filename = get_beautier_tempfilename(
+    pattern = "expected", fileext = ".xml"
+  )
 ) {
   if (!beautier::is_one_na(section)) {
     lines <- beautier::extract_xml_section_from_lines(
