@@ -4,6 +4,8 @@
 #' @param alignment_id ID of the alignment,
 #' as returned by \link{get_alignment_id}.
 #' Keep at \code{NA} to have it initialized automatically
+#' @param allow_empty_str allow a string to be empty
+#' @param allow_na allow \link{NA}
 #' @param alpha_parameter an alpha parameter,
 #' as created by \link{create_alpha_param}
 #' @param bd_tree_prior a Birth-Death tree prior, as created
@@ -46,6 +48,7 @@
 #' as a sequence.
 #' @param fasta_filenames One or more FASTA filenames.
 #'   Use \code{\link{get_fasta_filename}} to obtain a testing FASTA filename.
+#' @param filename a filename, as can be checked by \link{check_filename}
 #' @param fixed_crown_age determines if the phylogeny's crown age is
 #'   fixed. If FALSE, crown age is estimated by BEAST2. If TRUE,
 #'   the crown age is fixed to the crown age
@@ -195,6 +198,8 @@
 #'   functions to find the documentation parameters
 default_params_doc <- function(
   alignment_id,
+  allow_empty_str,
+  allow_na,
   alpha_parameter,
   bd_tree_prior,
   beautier_folder,
@@ -214,6 +219,7 @@ default_params_doc <- function(
   crown_age, crown_ages,
   distr_id,
   fasta_filename, fasta_filenames,
+  filename,
   fixed_crown_age,
   fixed_crown_ages,
   gamma_distr,
