@@ -9,24 +9,13 @@
 #' }
 #' @inheritParams default_params_doc
 #' @return lines of XML text
-#' @seealso all MRCA priors' tracelog section is created
-#'   by \code{\link{mrca_priors_to_xml_tracelog}}
 #' @author Richèl J.C. Bilderbeek
 #' @export
 mrca_prior_to_xml_tracelog <- function(
-  inference_model,
-  clock_models = "deprecated",
-  mrca_prior = "deprecated",
-  tipdates_filename = "deprecated"
+  inference_model
 ) {
-  testthat::expect_equal(clock_models, "deprecated")
-  testthat::expect_equal(mrca_prior, "deprecated")
-  testthat::expect_equal(tipdates_filename, "deprecated")
-
   # Do not be smart yet
-  clock_models <- list(inference_model$clock_model)
   mrca_prior <- inference_model$mrca_prior
-  tipdates_filename <- inference_model$tipdates_filename
 
   testit::assert(beautier::is_mrca_prior(mrca_prior))
   if (!beautier::has_mrca_prior(inference_model) &&
