@@ -9,8 +9,7 @@ remove_empty_lines <- function(lines, trim = FALSE) {
   trimmed <- stringr::str_trim(lines)
   if (trim == FALSE) {
     lines[stringr::str_length(trimmed) > 0]
-  }
-  else {
+  } else {
     trimmed[stringr::str_length(trimmed) > 0]
   }
 }
